======================
Sample Geospatial Data
======================

.. automodule:: pygeoprocessing.testing.sampledata
    :members: SRS_COLOMBIA, SRS_WILLAMETTE, dtype_precision, make_geotransform, visualize

.. End of file
